@@ -20,14 +20,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-try:
-    from .gateway import SoptGateway
-except ImportError:
-    pass
-
-
 import importlib_metadata
 
+from .gateway import SoptGateway
+
 
 try:
     __version__ = importlib_metadata.version("vnpy_sopt")
