@@ -1,10 +1,33 @@
 from pathlib import Path
-import pytz
 from datetime import datetime
 from time import sleep
-from vnpy.event.engine import EventEngine
 from typing import Dict, List, Tuple
 
+from vnpy.event import EventEngine
+from vnpy.trader.constant import (
+    Direction,
+    Offset,
+    Exchange,
+    OrderType,
+    Product,
+    Status,
+    OptionType
+)
+from vnpy.trader.gateway import BaseGateway
+from vnpy.trader.object import (
+    TickData,
+    OrderData,
+    TradeData,
+    PositionData,
+    AccountData,
+    ContractData,
+    OrderRequest,
+    CancelRequest,
+    SubscribeRequest,
+)
+from vnpy.trader.utility import get_folder_path, ZoneInfo
+from vnpy.trader.event import EVENT_TIMER
+
 from ..api import (
     MdApi,
     TdApi,
@@ -39,29 +62,6 @@ from ..api import (
     THOST_FTDC_VC_CV,
     THOST_FTDC_AF_Delete
 )
-from vnpy.trader.constant import (
-    Direction,
-    Offset,
-    Exchange,
-    OrderType,
-    Product,
-    Status,
-    OptionType
-)
-from vnpy.trader.gateway import BaseGateway
-from vnpy.trader.object import (
-    TickData,
-    OrderData,
-    TradeData,
-    PositionData,
-    AccountData,
-    ContractData,
-    OrderRequest,
-    CancelRequest,
-    SubscribeRequest,
-)
-from vnpy.trader.utility import get_folder_path
-from vnpy.trader.event import EVENT_TIMER
 
 
 # 委托状态映射
@@ -122,7 +122,7 @@ OPTIONTYPE_SOPT2VT: Dict[str, OptionType] = {
 }
 
 # 其他常量
-CHINA_TZ = pytz.timezone("Asia/Shanghai")       # 中国时区
+CHINA_TZ = ZoneInfo("Asia/Shanghai")       # 中国时区
 
 # 合约数据全局缓存字典
 symbol_contract_map: Dict[str, ContractData] = {}
@@ -130,12 +130,12 @@ symbol_contract_map: Dict[str, ContractData] = {}
 
 class SoptGateway(BaseGateway):
     """
-    vn.py用于对接期权CTP柜台的交易接口。
+    VeighNa用于对接期权CTP柜台的交易接口。
     """
 
     default_name: str = "SOPT"
 
-    default_setting = {
+    default_setting: Dict[str, str] = {
         "用户名": "",
         "密码": "",
         "经纪商代码": "",
@@ -203,7 +203,7 @@ class SoptGateway(BaseGateway):
         """输出错误信息日志"""
         error_id: int = error["ErrorID"]
         error_msg: str = error["ErrorMsg"]
-        msg = f"{msg}，代码：{error_id}，信息：{error_msg}"
+        msg: str = f"{msg}，代码：{error_id}，信息：{error_msg}"
         self.write_log(msg)
 
     def process_timer_event(self, event) -> None:
@@ -238,11 +238,11 @@ class SoptMdApi(MdApi):
 
         self.connect_status: bool = False
         self.login_status: bool = False
-        self.subscribed: List[str] = set()
+        self.subscribed: set = set()
 
-        self.userid = ""
-        self.password = ""
-        self.brokerid = ""
+        self.userid: str = ""
+        self.password: str = ""
+        self.brokerid: str = ""
 
     def onFrontConnected(self) -> None:
         """服务器连接成功回报"""
@@ -289,7 +289,7 @@ class SoptMdApi(MdApi):
 
         timestamp: str = f"{data['TradingDay']} {data['UpdateTime']}.{int(data['UpdateMillisec']/100)}"
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H:%M:%S.%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         tick: TickData = TickData(
             symbol=symbol,
@@ -476,10 +476,6 @@ class SoptTdApi(TdApi):
         """委托撤单失败回报"""
         self.gateway.write_error("交易撤单失败", error)
 
-    def onRspQueryMaxOrderVolume(self, data: dict, error: dict, reqid: int, last: bool) -> None:
-        """最大报单数量查询回报"""
-        pass
-
     def onRspSettlementInfoConfirm(self, data: dict, error: dict, reqid: int, last: bool) -> None:
         """确认结算单回报"""
         self.gateway.write_log("结算信息确认成功")
@@ -507,39 +503,39 @@ class SoptTdApi(TdApi):
             # 获取之前缓存的持仓数据缓存
             key: str = f"{data['InstrumentID'], data['PosiDirection']}"
             position: PositionData = self.positions.get(key, None)
-    
+
             if "&" in symbol:
                 exchange: Exchange = Exchange.SSE
             else:
                 exchange: Exchange = contract.exchange
-    
+
             if not position:
-                position: PositionData = PositionData(
+                position = PositionData(
                     symbol=symbol,
                     exchange=exchange,
                     direction=DIRECTION_SOPT2VT[data["PosiDirection"]],
                     gateway_name=self.gateway_name
                 )
                 self.positions[key] = position
-    
+
             # 计算昨仓
             position.yd_volume = data["Position"] - data["TodayPosition"]
-    
+
             # 获取合约的乘数信息
             size: int = contract.size
-    
+
             # 计算之前已有仓位的持仓总成本
             cost: float = position.price * position.volume * size
-    
+
             # 累加更新持仓数量和盈亏
             position.volume += data["Position"]
             position.pnl += data["PositionProfit"]
-    
+
             # 计算更新后的持仓总成本和均价
             if position.volume and size:
                 cost += data["PositionCost"]
                 position.price = cost / (position.volume * size)
-    
+
             # 更新仓位冻结数量
             if position.direction == Direction.LONG:
                 position.frozen += data["ShortFrozen"]
@@ -629,9 +625,9 @@ class SoptTdApi(TdApi):
 
         timestamp: str = f"{data['InsertDate']} {data['InsertTime']}"
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H:%M:%S")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
-        tp = (data["OrderPriceType"], data["TimeCondition"], data["VolumeCondition"])
+        tp: tuple = (data["OrderPriceType"], data["TimeCondition"], data["VolumeCondition"])
 
         order: OrderData = OrderData(
             symbol=symbol,
@@ -664,7 +660,7 @@ class SoptTdApi(TdApi):
 
         timestamp: str = f"{data['TradeDate']} {data['TradeTime']}"
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H:%M:%S")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         trade: TradeData = TradeData(
             symbol=symbol,
@@ -749,7 +745,7 @@ class SoptTdApi(TdApi):
 
         self.order_ref += 1
 
-        tp = ORDERTYPE_VT2SOPT[req.type]
+        tp: tuple = ORDERTYPE_VT2SOPT[req.type]
         price_type, time_condition, volume_condition = tp
 
         sopt_req: dict = {
@@ -826,18 +822,18 @@ class SoptTdApi(TdApi):
 
 def get_option_index(strike_price: float, exchange_instrument_id: str) -> str:
     """获取期权指数"""
-    exchange_instrument_id = exchange_instrument_id.replace(" ", "")
+    exchange_instrument_id: str = exchange_instrument_id.replace(" ", "")
 
     if "M" in exchange_instrument_id:
-        n = exchange_instrument_id.index("M")
+        n: int = exchange_instrument_id.index("M")
     elif "A" in exchange_instrument_id:
-        n = exchange_instrument_id.index("A")
+        n: int = exchange_instrument_id.index("A")
     elif "B" in exchange_instrument_id:
-        n = exchange_instrument_id.index("B")
+        n: int = exchange_instrument_id.index("B")
     else:
         return str(strike_price)
 
-    index = exchange_instrument_id[n:]
-    option_index = f"{strike_price:.3f}-{index}"
+    index: str = exchange_instrument_id[n:]
+    option_index: str = f"{strike_price:.3f}-{index}"
 
     return option_index
